import {
  jsonStringifySafe
} from "./chunk-VWBTJP5F.js";

// src/common/data/utils.ts
function ensureKey(obj, key, createFn) {
  let value = obj[key];
  if (value === void 0) {
    value = createFn(key, obj);
    obj[key] = value;
  }
  return value;
}
async function ensureKeyAsync(obj, key, createFn) {
  let value = obj[key];
  if (value === void 0) {
    value = await createFn(key, obj);
    obj[key] = value;
  }
  return value;
}
function size(obj) {
  if (obj != null) {
    if (obj.size != null)
      return obj.size;
    if (obj.length != null)
      return obj.length;
    return Object.keys(obj).length;
  }
  return 0;
}
function first(array) {
  return array != null && array.length > 0 ? array[0] : void 0;
}
function last(array) {
  return array != null && array.length > 0 ? array[array.length - 1] : void 0;
}
function empty(value) {
  try {
    if (value != null) {
      if (Array.isArray(value))
        return value.length <= 0;
      else if (typeof value === "string")
        return value.length <= 0;
      else if (value?.size != null)
        return value.size <= 0;
      else
        return Object.keys(value).length <= 0;
    }
  } catch (err) {
    console.warn("Failed to check if empty for", value, err);
  }
  return true;
}
function cloneObject(obj) {
  if (Object(obj) !== obj)
    return obj;
  return JSON.parse(jsonStringifySafe(obj));
}
function cloneJsonObject(obj) {
  if (Object(obj) !== obj)
    return obj;
  return JSON.parse(jsonStringifySafe(obj));
}
function memoize(fn) {
  const cache = /* @__PURE__ */ new Map();
  return (n) => {
    if (cache.has(n))
      return cache.get(n);
    const result = fn(n);
    cache.set(n, result);
    return result;
  };
}
function memoizeAsync(fn) {
  const cache = /* @__PURE__ */ new Map();
  return async (...n) => {
    const key = jsonStringifySafe(n);
    if (cache.has(key))
      return cache.get(key);
    const result = await fn(...n);
    cache.set(key, result);
    return result;
  };
}
function forTimes(count, fn) {
  const result = [];
  for (let i = 0; i < count; i++)
    result.push(fn(i, count));
  return result;
}

export {
  ensureKey,
  ensureKeyAsync,
  size,
  first,
  last,
  empty,
  cloneObject,
  cloneJsonObject,
  memoize,
  memoizeAsync,
  forTimes
};
//# sourceMappingURL=chunk-5BQNKE5C.js.map