"use strict";Object.defineProperty(exports, "__esModule", {value: true});

var _chunkQP5Y3I6Fcjs = require('./chunk-QP5Y3I6F.cjs');

// src/common/data/basex.ts
var alphabets = {
  "2": "01",
  "8": "01234567",
  "11": "0123456789a",
  "16": "0123456789abcdef",
  "32": "0123456789abcdefghjkmnpqrtuvwxyz",
  // Agnoster, because least mix up and good sorting
  "32-crockford": "0123456789ABCDEFGHJKMNPQRSTVWXYZ",
  // Crockford
  "32-geohash": "0123456789bcdefghjkmnpqrstuvwxyz",
  // https://en.wikipedia.org/wiki/Base32#Geohash
  "32-agnoster": "0123456789abcdefghjkmnpqrtuvwxyz",
  // https://github.com/agnoster/base32-js/blob/master/lib/base32.js#L6 without i(1), l(1), o(0), s(5); keeps sort order
  "32-rfc": "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567",
  // https://datatracker.ietf.org/doc/html/rfc4648#section-6
  "32-hex": "0123456789ABCDEFGHIJKLMNOPQRSTUV",
  // https://datatracker.ietf.org/doc/html/rfc4648#section-7
  "32-zbase": "ybndrfg8ejkmcpqxot1uwisza345h769",
  //  https://en.wikipedia.org/wiki/Base32#z-base-32
  "36": "0123456789abcdefghijklmnopqrstuvwxyz",
  "58": "123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz",
  "62": "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz",
  // Correct sort order
  "64": "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",
  "64-url": "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_",
  // https://datatracker.ietf.org/doc/html/rfc4648#section-5
  "66": "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_.!~",
  "85": "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz!#$%&()*+-;<=>?@^_`{|}~"
  // https://datatracker.ietf.org/doc/html/rfc1924#section-4.2
};
function _useBase(alphaOrBase) {
  let ALPHABET = alphabets[String(alphaOrBase)];
  if (!ALPHABET) {
    if (typeof alphaOrBase === "string")
      ALPHABET = alphaOrBase;
    else
      throw new Error(`Unknown base ${alphaOrBase}`);
  }
  if (ALPHABET.length >= 255)
    throw new TypeError("Alphabet too long");
  const BASE_MAP = new Uint8Array(256);
  for (let j = 0; j < BASE_MAP.length; j++)
    BASE_MAP[j] = 255;
  for (let i = 0; i < ALPHABET.length; i++) {
    const x = ALPHABET.charAt(i);
    const xc = x.charCodeAt(0);
    if (BASE_MAP[xc] !== 255)
      throw new TypeError(`${x} is ambiguous`);
    BASE_MAP[xc] = i;
  }
  const BASE = ALPHABET.length;
  const LEADER = ALPHABET.charAt(0);
  const FACTOR = Math.log(BASE) / Math.log(256);
  const iFACTOR = Math.log(256) / Math.log(BASE);
  function encode(source, padToLength = -1) {
    const data = _chunkQP5Y3I6Fcjs.toUint8Array.call(void 0, source);
    if (data.byteLength === 0)
      return "";
    let length = 0;
    let pbegin = 0;
    const pend = data.byteLength;
    while (pbegin !== pend && data[pbegin] === 0) pbegin++;
    const size = (pend - pbegin) * iFACTOR + 1 >>> 0;
    const dataEncoded = new Uint8Array(size);
    while (pbegin !== pend) {
      let carry = data[pbegin];
      let i = 0;
      for (let it1 = size - 1; (carry !== 0 || i < length) && it1 !== -1; it1--, i++) {
        carry += 256 * dataEncoded[it1] >>> 0;
        dataEncoded[it1] = carry % BASE >>> 0;
        carry = carry / BASE >>> 0;
      }
      if (carry !== 0) {
        throw new Error("Non-zero carry");
      }
      length = i;
      pbegin++;
    }
    let it2 = size - length;
    while (it2 !== size && dataEncoded[it2] === 0) it2++;
    let str = "";
    for (; it2 < size; ++it2) str += ALPHABET.charAt(dataEncoded[it2]);
    if (padToLength > 0) {
      return str.padStart(padToLength, LEADER);
    }
    return str;
  }
  function decode(source, padToLength = -1) {
    if (typeof source !== "string")
      throw new TypeError("Expected String");
    if (source.length === 0)
      return new Uint8Array();
    source = source.replace(/\s+/gi, "");
    let psz = 0;
    let length = 0;
    while (source[psz] === LEADER) psz++;
    const size = (source.length - psz) * FACTOR + 1 >>> 0;
    const dataDecoded = new Uint8Array(size);
    while (source[psz]) {
      let carry = BASE_MAP[source.charCodeAt(psz)];
      if (carry === 255)
        throw new Error(`Unsupported character "${source[psz]}"`);
      let i = 0;
      for (let it3 = size - 1; (carry !== 0 || i < length) && it3 !== -1; it3--, i++) {
        carry += BASE * dataDecoded[it3] >>> 0;
        dataDecoded[it3] = carry % 256 >>> 0;
        carry = carry / 256 >>> 0;
      }
      if (carry !== 0)
        throw new Error("Non-zero carry");
      length = i;
      psz++;
    }
    let it4 = size - length;
    while (it4 !== size && dataDecoded[it4] === 0) it4++;
    if (padToLength > 0) {
      return new Uint8Array([
        ...new Uint8Array(padToLength - dataDecoded.length + it4),
        ...dataDecoded.slice(it4)
      ]);
    }
    return dataDecoded.slice(it4);
  }
  return {
    encode,
    decode
  };
}
var cache;
function useBase(alphaOrBase) {
  if (cache == null)
    cache = /* @__PURE__ */ new Map();
  function getFromCache() {
    let fn = cache.get(alphaOrBase);
    if (fn == null) {
      fn = _useBase(alphaOrBase);
      cache.set(alphaOrBase, fn);
    }
    return fn;
  }
  function encode(source, padToLength = -1) {
    return getFromCache().encode(source, padToLength);
  }
  function decode(source, padToLength = -1) {
    return getFromCache().decode(source, padToLength);
  }
  return { encode, decode };
}
function encodeBase32(bin, padding = -1) {
  return useBase(32).encode(bin, padding);
}
function decodeBase32(s, padding = -1) {
  return useBase(32).decode(s.toLocaleLowerCase().replaceAll("l", "1").replaceAll("s", "5").replaceAll("o", "0").replaceAll("i", "1"), padding);
}
function encodeBase16(bin, padding = -1) {
  return useBase(16).encode(bin, padding);
}
function decodeBase16(s, padding = -1) {
  return useBase(16).decode(s, padding);
}
function encodeBase58(bin, padding = -1) {
  return useBase(58).encode(bin, padding);
}
function decodeBase58(s, padding = -1) {
  return useBase(58).decode(s, padding);
}
function encodeBase62(bin, padding = -1) {
  return useBase(62).encode(bin, padding);
}
function decodeBase62(s, padding = -1) {
  return useBase(62).decode(s, padding);
}
function estimateSizeForBase(bytes, base) {
  return Math.ceil(bytes * (Math.log(256) / Math.log(base)));
}













exports._useBase = _useBase; exports.useBase = useBase; exports.encodeBase32 = encodeBase32; exports.decodeBase32 = decodeBase32; exports.encodeBase16 = encodeBase16; exports.decodeBase16 = decodeBase16; exports.encodeBase58 = encodeBase58; exports.decodeBase58 = decodeBase58; exports.encodeBase62 = encodeBase62; exports.decodeBase62 = decodeBase62; exports.estimateSizeForBase = estimateSizeForBase;
//# sourceMappingURL=chunk-5K46PLWP.cjs.map