import {
  size
} from "./chunk-5BQNKE5C.js";

// src/common/data/is.ts
function isObject(obj) {
  return obj != null && typeof obj === "object";
}
function isFunction(obj) {
  return obj != null && typeof obj === "function";
}
function isBinaryArray(obj) {
  return obj instanceof Uint8Array || obj instanceof Uint8ClampedArray || obj instanceof Uint16Array || obj instanceof Uint32Array || obj instanceof Int8Array || obj instanceof Int16Array || obj instanceof Int32Array || obj instanceof Float32Array || obj instanceof Float64Array || obj instanceof BigInt64Array || obj instanceof BigUint64Array;
}
function isPrimitive(obj) {
  return Object(obj) !== obj;
}
function isArray(obj) {
  return Array.isArray(obj);
}
function isRecord(obj) {
  return isObject(obj) && !isArray(obj);
}
function isRecordPlain(obj) {
  return obj?.constructor === Object;
}
function isString(obj) {
  return typeof obj === "string";
}
function isNumber(obj) {
  return typeof obj === "number" && !Number.isNaN(obj);
}
function isInteger(obj) {
  return isNumber(obj) && Number.isInteger(obj);
}
function isSafeInteger(obj) {
  return isNumber(obj) && Number.isSafeInteger(obj);
}
function isBoolean(obj) {
  return typeof obj === "boolean";
}
function isSymbol(obj) {
  return typeof obj === "symbol";
}
function isNullOrUndefined(obj) {
  return obj == null;
}
function isNull(obj) {
  return obj == null;
}
function isUint8Array(obj) {
  return isObject(obj) && obj.constructor.name === "Uint8Array";
}
function isNotNull(value) {
  return value != null;
}
function isEmpty(value) {
  return value == null || value === "" || isObject(value) && size(value) <= 0;
}
function isNotEmpty(value) {
  return !isEmpty(value);
}
function isValue(value) {
  return value != null && value !== false && value !== true;
}
function isTruthy(value) {
  return value != null && value !== false && value !== 0 && value !== "";
}

export {
  isObject,
  isFunction,
  isBinaryArray,
  isPrimitive,
  isArray,
  isRecord,
  isRecordPlain,
  isString,
  isNumber,
  isInteger,
  isSafeInteger,
  isBoolean,
  isSymbol,
  isNullOrUndefined,
  isNull,
  isUint8Array,
  isNotNull,
  isEmpty,
  isNotEmpty,
  isValue,
  isTruthy
};
//# sourceMappingURL=chunk-AY5LGXTC.js.map