// src/common/platform.ts
function getWindow() {
  if (typeof window !== "undefined")
    return window;
}
function getNavigator() {
  if (typeof navigator !== "undefined")
    return navigator;
}
function getGlobal() {
  return getWindow() ?? typeof WorkerGlobalScope !== "undefined" ? self : typeof global !== "undefined" ? global : Function("return this;")();
}
function detect(info = {
  ios: false,
  macos: false,
  windows: false,
  beaker: false,
  electron: false,
  wkwebview: false,
  pwa: false,
  pwaInstalled: false,
  browser: false,
  node: false,
  worker: false,
  test: false,
  jest: false,
  macosNative: false,
  iosNative: false,
  appleNative: false,
  touch: false
}) {
  const _navigator = getNavigator();
  const _window = getWindow();
  info.ios = _navigator?.platform?.match(/(iPhone|iPod|iPad)/i) != null;
  info.macos = !!_navigator?.platform?.startsWith("Mac");
  info.windows = !!_navigator?.platform?.startsWith("Win");
  info.beaker = _window?.beaker != null;
  info.electron = (_navigator?.userAgent?.toLowerCase()?.indexOf(" electron/") || -1) > -1 && !info.beaker;
  info.wkwebview = _window?.webkit?.messageHandlers != null;
  info.pwa = _navigator?.serviceWorker != null;
  info.pwaInstalled = _navigator?.standalone || _window?.matchMedia?.("(display-mode: standalone)")?.matches;
  info.node = typeof process !== "undefined" && process?.release?.name === "node";
  info.browser = !info.electron && !info.wkwebview && !info.node;
  info.worker = typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope;
  info.jest = typeof jest !== "undefined" || typeof vitest !== "undefined";
  info.test = info.jest;
  info.macosNative = info.wkwebview && info.macos;
  info.iosNative = info.wkwebview && info.ios;
  info.appleNative = info.wkwebview;
  info.touch = _window && "ontouchstart" in _window || (_navigator?.maxTouchPoints || 0) > 1 || _navigator?.msPointerEnabled && _window?.MSGesture || _window?.DocumentTouch && document instanceof DocumentTouch;
  return info;
}
function isBrowser() {
  return typeof window !== "undefined" && globalThis === window;
}
function useExitHandler(handler) {
  if (isBrowser())
    window.addEventListener("beforeunload", handler);
  else if (typeof process !== "undefined")
    process.on("exit", () => handler);
}

export {
  getWindow,
  getNavigator,
  getGlobal,
  detect,
  isBrowser,
  useExitHandler
};
//# sourceMappingURL=chunk-LKHGPAZI.js.map