import {
  Uint8ArrayToHexDump
} from "./chunk-WG6ZJDFQ.js";

// src/common/data/convert.ts
var TRUE_VALUES_LIST = ["1", "true", "yes", "y", "on"];
function stringToBoolean(value, defaultValue = false) {
  if (value == null || typeof value !== "string")
    return defaultValue;
  return TRUE_VALUES_LIST.includes(String(value).trim().toLowerCase());
}
function stringToInteger(value, defaultValue = 0) {
  if (value == null || typeof value !== "string")
    return defaultValue;
  return Number.parseInt(value.trim(), 10) ?? defaultValue;
}
function stringToFloat(value, defaultValue = 0) {
  if (value == null || typeof value !== "string")
    return defaultValue;
  return Number.parseFloat(value.trim()) ?? defaultValue;
}
function valueToBoolean(value, defaultValue = false) {
  if (value == null)
    return defaultValue;
  if (typeof value === "boolean")
    return value;
  if (typeof value === "number")
    return value !== 0;
  return TRUE_VALUES_LIST.includes(String(value).trim().toLowerCase());
}
function valueToInteger(value, defaultValue = 0) {
  if (value == null)
    return defaultValue;
  if (typeof value === "boolean")
    return value ? 1 : 0;
  if (typeof value === "number")
    return Math.floor(value);
  return Number.parseInt(String(value).trim(), 10) ?? defaultValue;
}
function valueToFloat(value, defaultValue = 0) {
  if (value == null)
    return defaultValue;
  if (typeof value === "boolean")
    return value ? 1 : 0;
  if (typeof value === "number")
    return Math.floor(value);
  return Number.parseFloat(String(value).trim()) ?? defaultValue;
}
function valueToString(value, defaultValue = "") {
  if (value == null)
    return defaultValue;
  return String(value) ?? defaultValue;
}
var toFloat = valueToFloat;
var toInt = valueToInteger;
var toString = valueToString;
var toBool = valueToBoolean;
function formatMessages(messages, opt = {}) {
  const { trace = true, pretty = true } = opt;
  return messages.map((obj) => {
    if (obj && typeof obj === "object") {
      if (pretty && (obj instanceof Uint8Array || obj instanceof ArrayBuffer))
        return `
${Uint8ArrayToHexDump(obj)}
`;
      if (obj instanceof Error) {
        if (!trace)
          return `${obj.name || "Error"}: ${obj.message}`;
        return `${obj.name || "Error"}: ${obj.message}
${obj.stack}`;
      }
      try {
        return pretty ? JSON.stringify(obj, null, 2) : JSON.stringify(obj);
      } catch (err) {
      }
    }
    return String(obj);
  });
}
function renderMessages(messages, opt = {}) {
  return formatMessages(messages, opt).join(" ");
}
function fixBrokenUtf8String(brokenString) {
  try {
    return decodeURIComponent(escape(brokenString));
  } catch (e) {
  }
  return brokenString;
}

export {
  stringToBoolean,
  stringToInteger,
  stringToFloat,
  valueToBoolean,
  valueToInteger,
  valueToFloat,
  valueToString,
  toFloat,
  toInt,
  toString,
  toBool,
  formatMessages,
  renderMessages,
  fixBrokenUtf8String
};
//# sourceMappingURL=chunk-N5R4OMJA.js.map