"use strict";Object.defineProperty(exports, "__esModule", {value: true});

var _chunkTAKWLGAZcjs = require('./chunk-TAKWLGAZ.cjs');

// src/common/data/bin.ts
function _encodeUtf8Polyfill(str) {
  const encodedString = unescape(encodeURIComponent(str));
  const len = encodedString.length;
  const buf = new Uint8Array(len);
  for (let i = 0; i < len; i++)
    buf[i] = encodedString.codePointAt(i) || 0;
  return buf;
}
function _decodeUtf8Polyfill(buf) {
  let remainingLen = buf.length;
  let encodedString = "";
  let bufPos = 0;
  while (remainingLen > 0) {
    const nextLen = remainingLen < 1e4 ? remainingLen : 1e4;
    const bytes = buf.subarray(bufPos, bufPos + nextLen);
    bufPos += nextLen;
    encodedString += String.fromCodePoint.apply(null, bytes);
    remainingLen -= nextLen;
  }
  return decodeURIComponent(escape(encodedString));
}
var _textEncoder;
function stringToUInt8Array(text) {
  if (_textEncoder == null) {
    _textEncoder = _encodeUtf8Polyfill;
    if (typeof TextEncoder !== "undefined") {
      const encoder = new TextEncoder();
      _textEncoder = (data) => encoder.encode(data);
    }
  }
  return _textEncoder(text.normalize("NFC"));
}
var _textDecoder;
function Uint8ArrayToString(bin) {
  if (_textDecoder == null) {
    _textDecoder = _decodeUtf8Polyfill;
    if (typeof TextDecoder !== "undefined") {
      const decoder = new TextDecoder("utf-8", { ignoreBOM: true });
      _textDecoder = (data) => decoder.decode(data);
    }
  }
  return _textDecoder(bin).normalize("NFC");
}
function toUint8Array(data) {
  if (data instanceof ArrayBuffer)
    return new Uint8Array(data);
  if (typeof data === "string")
    return stringToUInt8Array(data);
  if (data.length)
    return new Uint8Array(data);
  return data;
}
function joinToUint8Array(...args) {
  let length = 0;
  const bins = args.flat(1).map((d) => {
    const b = toUint8Array(d);
    length += b.length;
    return b;
  });
  const bin = new Uint8Array(length);
  let cursor = 0;
  for (const b of bins) {
    bin.set(b, cursor);
    cursor += b.length;
  }
  return bin;
}
function toHex(bin) {
  if (typeof Buffer !== "undefined")
    return Buffer.from(toUint8Array(bin)).toString("hex");
  const h = "0123456789abcdef";
  let s = "";
  for (const v of [...toUint8Array(bin)])
    s += h[v >> 4] + h[v & 15];
  return s;
}
function fromHex(hexString) {
  return Uint8Array.from(
    hexString.match(/.{1,2}/g).map((byte) => Number.parseInt(byte, 16))
  );
}
function toBase64(bin, stripPadding = false) {
  const bytes = toUint8Array(bin);
  let sb = "";
  if (typeof Buffer !== "undefined") {
    sb = Buffer.from(bytes).toString("base64");
  } else {
    let s = "";
    for (let i = 0; i < bytes.byteLength; i++)
      s += String.fromCharCode(bytes[i]);
    sb = btoa(s);
  }
  if (stripPadding)
    return sb.replaceAll("=", "");
  return sb;
}
function toBase64Url(bin) {
  const bytes = toUint8Array(bin);
  if (typeof Buffer !== "undefined")
    return Buffer.from(bytes).toString("base64url").replaceAll("=", "");
  let s = "";
  for (let i = 0; i < bytes.byteLength; i++)
    s += String.fromCharCode(bytes[i]);
  return btoa(s).replaceAll("+", "-").replaceAll("/", "_").replaceAll("=", "");
}
function fromBase64(s) {
  s = s.replaceAll("-", "+").replaceAll("_", "/");
  if (typeof Buffer !== "undefined") {
    const buf = Buffer.from(s, "base64");
    return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength);
  }
  const a = atob(s);
  const bytes = new Uint8Array(a.length);
  for (let i = 0; i < a.length; i++)
    bytes[i] = a.charCodeAt(i);
  return bytes;
}
function fromBase64String(s) {
  return Uint8ArrayToString(fromBase64(s));
}
function equalBinary(a, b) {
  if (a.byteLength !== b.byteLength)
    return false;
  const aa = toUint8Array(a);
  const bb = toUint8Array(b);
  for (let i = 0; i < aa.length; i++) {
    if (aa[i] !== bb[i])
      return false;
  }
  return true;
}
function jsonToUint8Array(json) {
  return stringToUInt8Array(_chunkTAKWLGAZcjs.jsonStringifySafe.call(void 0, json));
}
function Uint8ArrayToJson(data) {
  return JSON.parse(Uint8ArrayToString(data));
}
function Uint8ArrayToHexDump(buffer, blockSize) {
  if (typeof buffer === "string") {
  } else if (buffer instanceof ArrayBuffer && buffer.byteLength !== void 0) {
    buffer = String.fromCharCode.apply(
      String,
      [].slice.call(new Uint8Array(buffer))
    );
  } else if (Array.isArray(buffer)) {
    buffer = String.fromCharCode.apply(String, buffer);
  } else if (buffer.constructor === Uint8Array) {
    buffer = String.fromCharCode.apply(String, [].slice.call(buffer));
  } else {
    return false;
  }
  blockSize = blockSize || 16;
  const lines = [];
  const hex = "0123456789abcdef";
  for (let b = 0; b < buffer.length; b += blockSize) {
    const block = buffer.slice(b, Math.min(b + blockSize, buffer.length));
    const addr = `0000${b.toString(16)}`.slice(-4);
    let codes = block.split("").map((ch) => {
      const code = ch.charCodeAt(0);
      return ` ${hex[(240 & code) >> 4]}${hex[15 & code]}`;
    }).join("");
    codes += "   ".repeat(blockSize - block.length);
    let chars = block.replace(/[\x00-\x1F\x20\x7F-\xA0\xAD]/g, ".");
    chars += " ".repeat(blockSize - block.length);
    lines.push(`${addr} ${codes}  ${chars}`);
  }
  return lines.join("\n");
}


















exports._encodeUtf8Polyfill = _encodeUtf8Polyfill; exports._decodeUtf8Polyfill = _decodeUtf8Polyfill; exports.stringToUInt8Array = stringToUInt8Array; exports.Uint8ArrayToString = Uint8ArrayToString; exports.toUint8Array = toUint8Array; exports.joinToUint8Array = joinToUint8Array; exports.toHex = toHex; exports.fromHex = fromHex; exports.toBase64 = toBase64; exports.toBase64Url = toBase64Url; exports.fromBase64 = fromBase64; exports.fromBase64String = fromBase64String; exports.equalBinary = equalBinary; exports.jsonToUint8Array = jsonToUint8Array; exports.Uint8ArrayToJson = Uint8ArrayToJson; exports.Uint8ArrayToHexDump = Uint8ArrayToHexDump;
//# sourceMappingURL=chunk-QP5Y3I6F.cjs.map