"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } }


var _chunkQP5Y3I6Fcjs = require('./chunk-QP5Y3I6F.cjs');

// src/common/crypto.ts
function randomUint8Array(length = 16) {
  const randomBytes = new Uint8Array(length);
  if (typeof crypto !== "undefined" && crypto.getRandomValues) {
    crypto.getRandomValues(randomBytes);
  } else {
    for (let i = 0; i < length; i++) {
      randomBytes[i] = Math.floor(Math.random() * 256);
    }
  }
  return randomBytes;
}
var CRYPTO_DEFAULT_HASH_ALG = "SHA-256";
var CRYPTO_DEFAULT_ALG = "AES-GCM";
var CRYPTO_DEFAULT_DERIVE_ALG = "PBKDF2";
var CRYPTO_DEFAULT_DERIVE_ITERATIONS = 1e5;
var CRYPTO_DEFAULT_IV_LENGTH = 12;
async function digest(message, algorithm = CRYPTO_DEFAULT_HASH_ALG) {
  return _chunkQP5Y3I6Fcjs.toUint8Array.call(void 0, 
    await crypto.subtle.digest(algorithm, _chunkQP5Y3I6Fcjs.toUint8Array.call(void 0, message))
  );
}
async function deriveKeyPbkdf2(secret, opt = {}) {
  const secretBuffer = _chunkQP5Y3I6Fcjs.toUint8Array.call(void 0, secret);
  const keyMaterial = await crypto.subtle.importKey(
    "raw",
    secretBuffer,
    CRYPTO_DEFAULT_DERIVE_ALG,
    false,
    ["deriveKey"]
  );
  return await crypto.subtle.deriveKey(
    {
      name: CRYPTO_DEFAULT_DERIVE_ALG,
      salt: opt.salt ? _chunkQP5Y3I6Fcjs.toUint8Array.call(void 0, opt.salt) : new Uint8Array(0),
      iterations: _nullishCoalesce(opt.iterations, () => ( CRYPTO_DEFAULT_DERIVE_ITERATIONS)),
      hash: CRYPTO_DEFAULT_HASH_ALG
    },
    keyMaterial,
    {
      name: CRYPTO_DEFAULT_ALG,
      length: 256
    },
    true,
    ["encrypt", "decrypt"]
  );
}
function getMagicId() {
  return new Uint8Array([1, 1]);
}
async function encrypt(data, key) {
  const MAGIC_ID = getMagicId();
  const iv = randomUint8Array(CRYPTO_DEFAULT_IV_LENGTH);
  const cipher = await crypto.subtle.encrypt(
    { name: CRYPTO_DEFAULT_ALG, iv },
    key,
    data
  );
  const binCypher = new Uint8Array(cipher);
  const bufferLength = MAGIC_ID.length + iv.length + binCypher.length;
  const buffer = new Uint8Array(bufferLength);
  let pos = 0;
  buffer.set(MAGIC_ID, pos);
  pos += MAGIC_ID.length;
  buffer.set(iv, pos);
  pos += iv.length;
  buffer.set(binCypher, pos);
  return buffer;
}
async function decrypt(data, key) {
  const magic = data.subarray(0, 2);
  if (!_chunkQP5Y3I6Fcjs.equalBinary.call(void 0, magic, getMagicId()))
    return Promise.reject(new Error(`Unknown magic ${magic}`));
  const iv = data.subarray(2, 2 + CRYPTO_DEFAULT_IV_LENGTH);
  const cipher = data.subarray(2 + CRYPTO_DEFAULT_IV_LENGTH, data.length);
  const plain = await crypto.subtle.decrypt(
    { name: CRYPTO_DEFAULT_ALG, iv },
    key,
    cipher
  );
  return new Uint8Array(plain);
}












exports.randomUint8Array = randomUint8Array; exports.CRYPTO_DEFAULT_HASH_ALG = CRYPTO_DEFAULT_HASH_ALG; exports.CRYPTO_DEFAULT_ALG = CRYPTO_DEFAULT_ALG; exports.CRYPTO_DEFAULT_DERIVE_ALG = CRYPTO_DEFAULT_DERIVE_ALG; exports.CRYPTO_DEFAULT_DERIVE_ITERATIONS = CRYPTO_DEFAULT_DERIVE_ITERATIONS; exports.CRYPTO_DEFAULT_IV_LENGTH = CRYPTO_DEFAULT_IV_LENGTH; exports.digest = digest; exports.deriveKeyPbkdf2 = deriveKeyPbkdf2; exports.encrypt = encrypt; exports.decrypt = decrypt;
//# sourceMappingURL=chunk-U7QCFBCQ.cjs.map