import {
  useLevelFilter,
  useNamespaceFilter
} from "./chunk-UJR57SSR.js";
import {
  getTimestamp
} from "./chunk-ZFRTRIT4.js";
import {
  objectPlain
} from "./chunk-DUQ7DD4G.js";

// src/common/log/log-memory.ts
function logMessageFromCompact(m) {
  const [timestamp, level, name, ...messages] = m;
  return { timestamp, level, name, messages };
}
function LoggerMemoryHandler(opt) {
  const { level = void 0, filter = void 0, compact = false, messages = [], errorTrace = false, maxDepth = 20 } = opt;
  const matchesNamespace = useNamespaceFilter(filter);
  const matchesLevel = useLevelFilter(level);
  let counter = opt.limit ?? Number.POSITIVE_INFINITY;
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    msg.timestamp ?? (msg.timestamp = getTimestamp());
    const m = objectPlain(msg, { maxDepth, errorTrace });
    if (compact === true)
      messages.push([m.timestamp, m.level, m.name, ...m.messages]);
    else
      messages.push(m);
    if (counter <= 0)
      messages.shift();
    else
      --counter;
  };
}

export {
  logMessageFromCompact,
  LoggerMemoryHandler
};
//# sourceMappingURL=chunk-XWWQZH6C.js.map