// src/common/time.ts
function getTimestamp() {
  return Date.now();
}
function formatMilliseconds(ms) {
  return ms > 999 ? `${(ms / 1e3).toFixed(1)} s` : `${ms.toFixed(2)} ms`;
}
function parseDate(...dateCandidates) {
  for (const dateCandidate of dateCandidates) {
    if (dateCandidate instanceof Date)
      return dateCandidate;
    if (typeof dateCandidate === "string") {
      let date = null;
      if (dateCandidate.includes(":")) {
        try {
          date = new Date(dateCandidate);
        } catch (err) {
        }
      }
      if (!(date instanceof Date)) {
        const m = /(\d\d\d\d)-(\d\d)-(\d\d)/.exec(dateCandidate);
        if (m)
          date = new Date(+m[1], +m[2] - 1, +m[3], 12, 0);
      }
      if (date instanceof Date)
        return date;
    }
  }
}
function getPerformanceTimestamp() {
  return typeof performance !== "undefined" ? performance.now() : Date.now();
}
function duration() {
  const t0 = getPerformanceTimestamp();
  return function() {
    const duration2 = getPerformanceTimestamp() - t0;
    return formatMilliseconds(duration2);
  };
}
function datetimeToLocal(fromDate) {
  return new Date(
    fromDate.getUTCFullYear(),
    fromDate.getUTCMonth(),
    fromDate.getUTCDate(),
    fromDate.getUTCHours(),
    fromDate.getUTCMinutes(),
    fromDate.getUTCSeconds(),
    fromDate.getUTCMilliseconds()
  );
}
function datetimeToUTC(fromDate) {
  return new Date(Date.UTC(
    fromDate.getFullYear(),
    fromDate.getMonth(),
    fromDate.getDate(),
    fromDate.getHours(),
    fromDate.getMinutes(),
    fromDate.getSeconds(),
    fromDate.getMilliseconds()
  ));
}

export {
  getTimestamp,
  formatMilliseconds,
  parseDate,
  getPerformanceTimestamp,
  duration,
  datetimeToLocal,
  datetimeToUTC
};
//# sourceMappingURL=chunk-ZFRTRIT4.js.map