import {
  csvParse,
  csvParseToObjects,
  csvStringify
} from "../chunk-B44DP4LU.js";
import "../chunk-36ARYR6V.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-FPJHSFML.js";
import "../chunk-3SMFSMCY.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-DUQ7DD4G.js";
import "../chunk-XHROZN2O.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-2PY7FMFN.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-DXSTF7NX.js";
import "../chunk-AY5LGXTC.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-N5R4OMJA.js";
import "../chunk-SOTGICOC.js";
import "../chunk-MVRB7Y7X.js";
import "../chunk-FSDCRQB3.js";
import "../chunk-MRFHKDNG.js";
import "../chunk-DUON5DN5.js";
import "../chunk-GY34N3KU.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-JJD2XTS2.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-5BQNKE5C.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-WG6ZJDFQ.js";
import "../chunk-VWBTJP5F.js";
import "../chunk-LRAR7IPU.js";

// src/common/csv.spec.ts
describe("csv.spec", () => {
  it("should generate csv", async () => {
    const txt = csvStringify([
      [1, "one", 1e10, "1e10", 1.23],
      [2, "two\nlines", null, void 0, true],
      [3, 'tree "drei"', {}, { a: 1 }, [1, 2, 3]]
    ]);
    expect(txt).toMatchInlineSnapshot(`
      "1,one,10000000000,1e10,1.23
      2,"two
      lines",,,1
      3,"tree ""drei""",{},"{""a"":1}","[1,2,3]"
      "
    `);
    expect(csvParse(txt)).toMatchInlineSnapshot(`
      Array [
        Array [
          "1",
          "one",
          "10000000000",
          "1e10",
          "1.23",
        ],
        Array [
          "2",
          "two
      lines",
          "",
          "",
          "1",
        ],
        Array [
          "3",
          "tree "drei"",
          "{}",
          "{"a":1}",
          "[1,2,3]",
        ],
      ]
    `);
  });
  it("should parse", () => {
    const sample = `"Zeitpunkt";"timestamp";"D0";"V0";"V0_max";"T0";"F0";"G0";"S0";"R0";"M0";"T1";"L0";"L0_nn"
"26.10.2022, 23:00";"1666825201";"155";"4";"6";"146";"80";"9";"0";"0";"0";"135";"0";"10102"
"26.10.2022, 23:10";"1666825801";"161";"4";"7";"145";"80";"8";"0";"0";"0";"135";"0";"10102"
"26.10.2022, 23:20";"1666826401";"160";"4";"7";"145";"81";"9";"0";"0";"0";"135";"0";"10102"
"26.10.2022, 23:30";"1666827001";"160";"4";"7";"145";"81";"8";"0";"0";"0";"134";"0";"10102"
"26.10.2022, 23:40";"1666827601";"151";"4";"7";"145";"81";"9";"0";"0";"0";"134";"0";"10102"
"26.10.2022, 23:50";"1666828201";"149";"4";"7";"147";"80";"9";"0";"0";"0";"137";"0";"10102"
"27.10.2022, 00:00";"1666828801";"151";"4";"7";"147";"80";"9";"0";"0";"0";"137";"0";"10102"
"27.10.2022, 00:10";"1666829401";"154";"4";"6";"148";"80";"9";"0";"0";"0";"137";"0";"10102"
"27.10.2022, 00:20";"1666830001";"150";"4";"7";"147";"80";"9";"0";"0";"0";"137";"0";"10102"`;
    const objs = csvParseToObjects(sample, { separator: ";" });
    expect(objs.slice(0, 3)).toMatchInlineSnapshot(`
      Array [
        Object {
          "D0": "155",
          "F0": "80",
          "G0": "9",
          "L0": "0",
          "L0_nn": "10102",
          "M0": "0",
          "R0": "0",
          "S0": "0",
          "T0": "146",
          "T1": "135",
          "V0": "4",
          "V0_max": "6",
          "Zeitpunkt": "26.10.2022, 23:00",
          "timestamp": "1666825201",
        },
        Object {
          "D0": "161",
          "F0": "80",
          "G0": "8",
          "L0": "0",
          "L0_nn": "10102",
          "M0": "0",
          "R0": "0",
          "S0": "0",
          "T0": "145",
          "T1": "135",
          "V0": "4",
          "V0_max": "7",
          "Zeitpunkt": "26.10.2022, 23:10",
          "timestamp": "1666825801",
        },
        Object {
          "D0": "160",
          "F0": "81",
          "G0": "9",
          "L0": "0",
          "L0_nn": "10102",
          "M0": "0",
          "R0": "0",
          "S0": "0",
          "T0": "145",
          "T1": "135",
          "V0": "4",
          "V0_max": "7",
          "Zeitpunkt": "26.10.2022, 23:20",
          "timestamp": "1666826401",
        },
      ]
    `);
    const data = csvParse(sample, { separator: ";" });
    expect(data.slice(0, 3)).toMatchInlineSnapshot(`
      Array [
        Array [
          "Zeitpunkt",
          "timestamp",
          "D0",
          "V0",
          "V0_max",
          "T0",
          "F0",
          "G0",
          "S0",
          "R0",
          "M0",
          "T1",
          "L0",
          "L0_nn",
        ],
        Array [
          "26.10.2022, 23:00",
          "1666825201",
          "155",
          "4",
          "6",
          "146",
          "80",
          "9",
          "0",
          "0",
          "0",
          "135",
          "0",
          "10102",
        ],
        Array [
          "26.10.2022, 23:10",
          "1666825801",
          "161",
          "4",
          "7",
          "145",
          "80",
          "8",
          "0",
          "0",
          "0",
          "135",
          "0",
          "10102",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=csv.spec.js.map