import {
  detect
} from "../../chunk-LKHGPAZI.js";
import {
  Emitter,
  getGlobalEmitter
} from "../../chunk-3PCE3IPH.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-XWWQZH6C.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-Y7J6ADHV.js";
import "../../chunk-OKUAPZFI.js";
import "../../chunk-QS2OVW4B.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-UJR57SSR.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-36ARYR6V.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-FPJHSFML.js";
import "../../chunk-3SMFSMCY.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-DUQ7DD4G.js";
import "../../chunk-XHROZN2O.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-2PY7FMFN.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-DXSTF7NX.js";
import "../../chunk-AY5LGXTC.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-N5R4OMJA.js";
import "../../chunk-SOTGICOC.js";
import "../../chunk-MVRB7Y7X.js";
import {
  sleep,
  waitOn
} from "../../chunk-FSDCRQB3.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-DUON5DN5.js";
import "../../chunk-GY34N3KU.js";
import {
  getSecureRandomIfPossible
} from "../../chunk-IZT6OHMS.js";
import "../../chunk-JJD2XTS2.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-5BQNKE5C.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-WG6ZJDFQ.js";
import "../../chunk-VWBTJP5F.js";
import "../../chunk-LRAR7IPU.js";

// src/common/msg/emitter.spec.ts
import { vi } from "vitest";
var platform = detect();
function lazyListener(emitter, listenerKey) {
  const name = Math.round(getSecureRandomIfPossible() * 100);
  const events = [];
  let lazyResolve;
  const incoming = (key, obj) => {
    const ev = { key, obj };
    events.push(ev);
    lazyResolve && lazyResolve();
  };
  if (listenerKey) {
    if (emitter.on) {
      emitter.on(listenerKey, (obj) => {
        incoming(listenerKey, obj);
      });
    } else if (emitter.addEventListener) {
      emitter.addEventListener(listenerKey, (obj) => {
        incoming(listenerKey, obj);
      });
    } else {
      emitter.log.error(name, "Cannot listen to key");
    }
  } else {
    if (emitter.onAny) {
      emitter.onAny((key, obj) => {
        incoming(key, obj);
      });
    } else {
      emitter.log.error(name, "cannot listen to all for", emitter);
    }
  }
  const on = (key, skipUnmatched = true) => {
    return new Promise((resolve, reject) => {
      if (!key) {
        key = listenerKey;
        if (!key) {
          if (events.length) {
            key = events[0].key;
          }
        }
      }
      lazyResolve = () => {
        while (events.length > 0) {
          const ev = events.shift();
          if (ev.key === key) {
            lazyResolve = void 0;
            resolve(ev.obj);
          } else {
            if (skipUnmatched) {
              continue;
            }
            reject(new Error(`Expected ${key}, but found ${ev.key} with value=${ev.obj}`));
          }
          break;
        }
      };
      lazyResolve();
    });
  };
  return on;
}
describe("emitter", () => {
  it("should emit", async () => {
    expect.assertions(4);
    let ctr = 0;
    const e = new Emitter();
    e.on("test", (x, y) => expect(x + y).toBe(123));
    e.on("long", async () => {
      await sleep(500);
      ctr++;
    });
    const ee = e.call;
    await ee.long();
    expect(ctr).toBe(1);
    e.onCall({
      test(x, y) {
        expect(x + y).toBe(123);
      }
    });
    await e.emit("long");
    expect(ctr).toBe(2);
    await e.emit("test", 100, 23);
  });
  it("should work", async () => {
    const e1 = new Emitter();
    const e2 = new Emitter();
    let counter = 99;
    e1.on("a", () => counter++);
    e2.on("a", () => counter--);
    e2.on("b", () => counter--);
    void e1.emit("a");
    expect(counter).toBe(100);
    void e2.emit("a");
    void e2.emit("b");
    expect(counter).toBe(98);
    e1.on("a", () => counter++);
    void e1.emit("a");
    expect(counter).toBe(100);
    e1.removeAllListeners();
    void e1.emit("a");
    expect(counter).toBe(100);
  });
  it("should wait on", async () => {
    expect.assertions(2);
    const e1 = new Emitter();
    setTimeout(() => {
      void e1.emit("f", 1);
    }, 100);
    const v = await waitOn(e1, "f");
    expect(v).toBe(1);
    if (platform.test) {
      await expect(waitOn(e1, "x", 10)).rejects.toThrow(
        "Did not response in time"
      );
    }
  });
  it("should work lazy", async () => {
    const e1 = new Emitter();
    const e2 = new Emitter();
    const on1 = lazyListener(e1);
    const on2 = lazyListener(e2);
    await e1.emit("a", 1);
    await e1.emit("b", 2);
    await e2.emit("a", 3);
    expect(await on2("a")).toBe(3);
    expect(await on1("b")).toBe(2);
  });
  it("should expect events", async () => {
    expect.assertions(3);
    const e = new Emitter();
    e.on("a", (v) => expect(v).toBe(1));
    e.on("a", (v) => expect(v).toBe(1));
    e.on("b", (v) => expect(v).toBe(1));
    await e.emit("a", 1);
    await e.emit("b", 1);
  });
  it("should expect once", async () => {
    expect.assertions(1);
    const e = new Emitter();
    e.once("a", (v) => expect(v).toBe(1));
    void e.emit("a", 1);
    void e.emit("a", 2);
    void e.emit("a", 3);
  });
  it("should mock events", async () => {
    const fn = vi.fn();
    const e = new Emitter();
    e.on("a", fn);
    e.on("a", fn);
    e.on("b", fn);
    await e.emit("a", 1);
    await e.emit("b", 1);
    expect(fn).toBeCalledTimes(3);
  });
  it("should work with global listener", async () => {
    const fn = vi.fn();
    const e = getGlobalEmitter();
    e.on("a", fn);
    e.on("a", fn);
    e.on("b", fn);
    await e.emit("a", 1);
    await getGlobalEmitter().emit("b", 2);
    expect(fn).toBeCalledTimes(3);
    expect(fn.mock).toMatchInlineSnapshot(`
      Object {
        "calls": Array [
          Array [
            1,
          ],
          Array [
            1,
          ],
          Array [
            2,
          ],
        ],
        "instances": Array [
          undefined,
          undefined,
          undefined,
        ],
        "invocationCallOrder": Array [
          4,
          5,
          6,
        ],
        "lastCall": Array [
          2,
        ],
        "results": Array [
          Object {
            "type": "return",
            "value": undefined,
          },
          Object {
            "type": "return",
            "value": undefined,
          },
          Object {
            "type": "return",
            "value": undefined,
          },
        ],
      }
    `);
  });
  it("should respect priorities", async () => {
    const e = new Emitter();
    const l = [];
    e.on("p", () => l.push(2), { priority: 100 });
    e.on("p", () => l.push(5), { priority: -1 });
    e.on("p", () => l.push(6), { priority: -2 });
    e.on("p", () => l.push(1), { priority: 110 });
    e.on("p", () => l.push(3));
    e.on("p", () => l.push(4));
    await e.emit("p");
    expect(l).toEqual([1, 2, 3, 4, 5, 6]);
  });
});
export {
  lazyListener
};
//# sourceMappingURL=emitter.spec.js.map