import {
  decodeJson,
  encodeJson
} from "../../chunk-HOL3CDR5.js";
import "../../chunk-YNHWGFAP.js";
import "../../chunk-56A7O3ON.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-PDBCA7WB.js";
import {
  useRPC,
  useRPCHub
} from "../../chunk-2QDXP3IF.js";
import {
  createLocalChannelPair
} from "../../chunk-FA3Y54NL.js";
import "../../chunk-YQIRRU73.js";
import "../../chunk-3PCE3IPH.js";
import "../../chunk-WEBXXRYZ.js";
import "../../chunk-OQ2AACIR.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-XWWQZH6C.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-Y7J6ADHV.js";
import "../../chunk-OKUAPZFI.js";
import "../../chunk-QS2OVW4B.js";
import "../../chunk-7IUVQQ4S.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-UJR57SSR.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-36ARYR6V.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-FPJHSFML.js";
import "../../chunk-3SMFSMCY.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-DUQ7DD4G.js";
import "../../chunk-XHROZN2O.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-2PY7FMFN.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-DXSTF7NX.js";
import "../../chunk-AY5LGXTC.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-N5R4OMJA.js";
import "../../chunk-SOTGICOC.js";
import "../../chunk-MVRB7Y7X.js";
import {
  sleep
} from "../../chunk-FSDCRQB3.js";
import "../../chunk-MRFHKDNG.js";
import "../../chunk-DUON5DN5.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-JJD2XTS2.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-5BQNKE5C.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-WG6ZJDFQ.js";
import "../../chunk-VWBTJP5F.js";
import "../../chunk-LRAR7IPU.js";

// src/common/msg/rpc.spec.ts
import { MessageChannel } from "node:worker_threads";
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc async", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("hub", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("timeout async", async (done) => {
    const [f1, f2] = createLocalChannelPair();
    const rpc1 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_1`;
      }
    }, {
      post: (data) => {
        f1.postMessage(data);
      },
      on: (data) => f1.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const rpc2 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_2`;
      }
    }, {
      post: (data) => {
        f2.postMessage(data);
      },
      on: (data) => f2.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const r = await rpc1.echo("abc");
    expect(r).toMatchInlineSnapshot(`"abc_2"`);
    try {
      const r2 = await rpc1.echo("abc", 50);
      expect(false).toBe(true);
    } catch (err) {
      expect(err).toMatchInlineSnapshot(`[Error: rpc timeout on calling "echo"]`);
    }
  });
  it("async", async (done) => {
    function echo(n) {
      return n;
    }
    async function echoAsync(n) {
      return n;
    }
    expect(await echo(1)).toBe(1);
    expect(await echoAsync(2)).toBe(2);
  });
});
//# sourceMappingURL=rpc.spec.js.map